==> node-input-validator-1.1.2.tgz: package/test/required-rules.js <==
const assert = require('assert');

const should = require('should');

const Validator = require('../index');

let r = {};

describe('requiredRules', function () {

    describe('required', function () {

        it('should return true', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh'}, {name: 'required'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator(r, {name: ''}, {name: 'required'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('name');

        });

    });


    describe('requiredIf', function () {

        it('should return true', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', sex: 'male', age: 16}, {sex: 'requiredIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', age: 16}, {sex: 'requiredIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('sex');

        });

    });


    describe('requiredNotIf', function () {

        it('should return true', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', age: '16'}, {sex: 'requiredNotIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', age: '15'}, {sex: 'requiredNotIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('sex');

        });

    });


    describe('requiredWith', function () {

        it('should return true', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', sex: 'male',  email: '', ip:''}, {email: 'email', ip: 'requiredWith:email|ip'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', sex: 'male',  email: 'artisangang@gmail.com', ip:''}, {email: 'email', ip: 'requiredWith:email|ip'});


            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('ip');

        });

    });



    describe('requiredWithout', function () {

        it('should return true', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh', sex: 'male', age:'23'}, {sex: 'requiredWithout:age'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator(r, {name: 'Harcharan Singh'}, {sex: 'requiredWithout:age'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('sex');

        });

    });

});

==> node-input-validator-2.0.1.tgz: package/test/required-rules.js <==
const assert = require('assert');

const should = require('should');

const Validator = require('../index');

let r = {};

describe('requiredRules', function () {

    describe('required', function () {

        it('should return true', async () => {

            let v = new Validator({name: 'Harcharan Singh'}, {name: 'required'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator({name: ''}, {name: 'required'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('name');

        });

    });


    describe('requiredIf', function () {

        it('should return true', async () => {

            let v = new Validator( {name: 'Harcharan Singh', sex: 'male', age: 16}, {sex: 'requiredIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator( {name: 'Harcharan Singh', age: 16}, {sex: 'requiredIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('sex');

        });

    });


    describe('requiredNotIf', function () {

        it('should return true', async () => {

            let v = new Validator( {name: 'Harcharan Singh', age: '16'}, {sex: 'requiredNotIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator( {name: 'Harcharan Singh', age: '15'}, {sex: 'requiredNotIf:age,16'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('sex');

        });

    });


    describe('requiredWith', function () {

        it('should return true', async () => {

            let v = new Validator( {name: 'Harcharan Singh', sex: 'male',  email: '', ip:''}, {email: 'email', ip: 'requiredWith:email|ip'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator( {name: 'Harcharan Singh', sex: 'male',  email: 'artisangang@gmail.com', ip:''}, {email: 'email', ip: 'requiredWith:email|ip'});


            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('ip');

        });

    });



    describe('requiredWithout', function () {

        it('should return true', async () => {

            let v = new Validator( {name: 'Harcharan Singh', sex: 'male', age:'23'}, {sex: 'requiredWithout:age'});

            let matched = await v.check();

            assert.equal(matched, true);

        });

        it('should return false', async () => {

            let v = new Validator( {name: 'Harcharan Singh'}, {sex: 'requiredWithout:age'});

            let matched = await v.check();

            assert.equal(matched, false);

            should(v.errors).be.an.instanceOf(Object);
            should(v.errors).have.property('sex');

        });

    });

});
